#!/bin/bash

/tmp/splunk/bin/splunk edit user admin -password notchangeme --accept-license --answer-yes --no-prompt -auth admin:changeme
/tmp/splunk/bin/splunk start --accept-license --answer-yes --no-prompt

if [[ "$1" == "lm" ]];then
	./cluster/lm.sh
elif [[ "$1" == "master" ]]; then
	./cluster/master.sh
elif [[ "$1" == "indexer" ]]; then
	./cluster/indexer.sh
elif [[ "$1" == "sh" ]]; then
	./cluster/sh.sh
#elif [[ "$1" == "dps" ]]; then
#	./cluster/dps.sh
#elif [[ "$1" == "fwdr" ]]; then
#	./cluster/fwdr.sh
#

# distributed search
elif [[ "$1" == "dsh" ]]; then
	./cluster/dsh.sh
elif [[ "$1" == "dsp" ]]; then
    ./cluster/dsp.sh

# seach head clustering
elif [[ "$1" == "shcsp" ]]; then
	./cluster/shcsp.sh
elif [[ "$1" == "shcshc" ]]; then
    ./cluster/shcshc.sh
elif [[ "$1" == "shcdpy" ]]; then
	./cluster/shcdpy.sh
elif [[ "$1" == "shcsh" ]]; then
    ./cluster/shcsh.sh


# multi-sites cluster
elif [[ "$1" == "multimaster" ]]; then
    ./cluster/multimaster.sh $2 $3 $4
elif [[ "$1" == "siteindexer" ]]; then
	# sleep 1m
	./cluster/siteindexer.sh $2
elif [[ "$1" == "sitesh" ]]; then
	# sleep 1m
	./cluster/sitesh.sh $2
fi
#if [ ! -f /.root_pw_set ]; then
#        /set_root_pw.sh
#fi

echo "I am splunk coreqa engineer"
/tmp/splunk/bin/splunk start && exec /usr/sbin/sshd -D && sh -c "while true;do echo i am here;sleep 60;done"
                                 